import { ExpressWave } from './express-wave';
export declare const CDK_EXPRESS_PIPELINE_DEPENDENCY_REASON = "cdk-express-pipeline wave->stage->stack dependency";
export declare const CDK_EXPRESS_PIPELINE_DEFAULT_SEPARATOR = "_";
export interface CdkExpressPipelineProps {
    /**
     * The waves in the pipeline
     */
    readonly waves?: ExpressWave[];
    /** Separator between the wave, stage and stack ids that are concatenated to form the stack id
     * @default __ */
    readonly separator?: string;
}
/**
 * A CDK Express Pipeline that defines the order in which the stacks are deployed
 */
export declare class CdkExpressPipeline {
    readonly waves: ExpressWave[];
    private separator;
    constructor(props?: CdkExpressPipelineProps);
    /** Add a wave to the pipeline
     * @param id The wave identifier
     */
    addWave(id: string): ExpressWave;
    /** Synthesize the pipeline which creates the dependencies between the stacks in the correct order
     * @param waves The waves to synthesize
     * @param print Whether to print the order of deployment to the console
     */
    synth(waves?: ExpressWave[], print?: boolean): void;
    /**
     * Print the order of deployment to the console
     * @param waves
     * @private
     */
    private printWaves;
}
export default CdkExpressPipeline;
