import { ExpressStage } from './express-stage';
export interface IExpressWave {
    /**
     * The wave identifier
     */
    id: string;
    /**
     * Separator between the wave, stage and stack ids that are concatenated to form the final stack id
     */
    separator: string;
    /**
     * The ExpressStages in the wave
     */
    stages: ExpressStage[];
    /**
     * Add an ExpressStage to the wave
     * @param id The ExpressStage identifier
     */
    addStage(id: string): ExpressStage;
}
export interface ExpressWaveProps {
    readonly id: string;
    /**
     * Separator between the wave, stage and stack ids that are concatenated to form the stack id
     * @default `_`
     */
    readonly separator?: string;
}
/**
 * A CDK Express Pipeline Wave that contains ExpressStages
 */
export declare class ExpressWave implements IExpressWave {
    id: string;
    separator: string;
    stages: ExpressStage[];
    /**
     * Constructs a new instance of the ExpressWave class
     * @param id
     * @param separator Separator between the wave, stage and stack ids that are concatenated to form the stack id. Default: '_'.
     */
    constructor(id: string, separator?: string);
    addStage(id: string): ExpressStage;
}
